@@ -137,6 +137,12 @@ class WriteConfigFile(Command):
     def check_args(self):
         return True
 
+    def check_item(self, search_item, search_list):
+        for item in search_list:
+            if search_item in item:
+                return item
+        return False
+
     def execute(self):
         # obtener el cliente a partir del nombre
         arg = self._args
@@ -181,16 +187,22 @@ class WriteConfigFile(Command):
         else:
             # no estoy en modo debug,
             # si no defino workers en el manifiesto lo calculo
-            if 'workers' not in conf:
+            line = self.check_item('workers', conf)
+            if not line:
                 # Calculo los workers
                 # You should use 2 worker threads CPU
                 odoo_conf.add_line('workers = %s' % (os.cpu_count() * 2))
+            else:
+                odoo_conf.add_line(line)
 
             # si no defino cron_threads en el manifiesto lo calculo
-            if 'max_cron_threads' not in conf:
+            line = self.check_item('max_cron_threads', conf)
+            if not line:
                 # Calculo los cron threads
                 # You should use 1 cron thread per available CPU
                 odoo_conf.add_line('max_cron_threads = %s' % os.cpu_count())
+            else:
+                odoo_conf.add_line(line)
 
         odoo_conf.write_config()
 
